@@ -713,22 +713,29 @@ class Application extends ApplicationConfig
      * @access public
      * @param string | array $params and values array
      */
-   function redirect ($action,$plist=array())
-    {
+    function redirect ($action,$plist=array(),$redirect_base='')
+   {
 
         $params = '';
 
         // redirect to another script if "?" given
         @list($script,$ca) = explode('?',$action);
         if ($ca) {
-            $redir_to = dirname($_SERVER['SCRIPT_NAME']).'/'.$script;
+            $script_name = dirname($_SERVER['SCRIPT_NAME']).'/'.$script;
             $params .= $ca;
         }
         else {
-            $redir_to  = $_SERVER['SCRIPT_NAME'];
+            $script_name  = $_SERVER['SCRIPT_NAME'];
             $params .= 'CA='.$action;
         }
 
+        if ($redirect_base) {
+            $redir_to = $redirect_base;
+        }
+        else {
+            $redir_to = $script_name;
+        }
+
         if ($this->DEBUG) {
             $this->log("REDIRECT ===> $redir_to?$params",2,'SPAF2/App');
             $this->log("------------------------------------------",2,'SPAF2/App');
@@ -777,15 +784,10 @@ class Application extends ApplicationConfig
         }
 
         // HTTP CONFIGURATION
-        if ($redirect_base = $this->getConfig('REDIRECT_BASE')) {
-            $location = 'Location: '.$redirect_base.$redir_to."?$params";
-        }
-        else {
-            if ($http_port) {
-                $http_host = $http_host.':'.$http_port;
-            }
-            $location = 'Location: '.$http_proto.$http_host.$redir_to."?$params";
+        if ($http_port) {
+            $http_host = $http_host.':'.$http_port;
         }
+        $location = 'Location: '.$http_proto.$http_host.$redir_to."?$params";
 
         header($location);
         exit();
