@@ -37,6 +37,12 @@ $attachmentId = $App->getParam('attachmentId');
 $contentType = $App->getParam('type');
 $sessionMailId = $App->getParam('id');
 
+$disposition = 'attachment';
+$show_inline = $App->getConfigList('ATTACHMENT_INLINE',array('application/pdf','image/png'));
+if (in_array($contentType,$show_inline)) {
+    $disposition = 'inline';
+}
+
 try {
     $filename = urlencode($filename);
     $attachmentData = $Backend->fetchAttachment($archive,$sessionMailId,$filename, $attachmentId);
@@ -44,7 +50,7 @@ try {
     header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
     header("Pragma: public");
     header('Content-Type: '.$contentType);
-    header("Content-Disposition: attachment; filename=\"$filename\";");
+    header("Content-Disposition: $disposition; filename=\"$filename\";");
 
     print $attachmentData;
     exit;
