@@ -62,7 +62,7 @@ $rest_user = $RESTconf->getConfig('REST_USER','benno2');
 $rest_pass = $RESTconf->getConfig('SHARED_SECRET',$App->getConfig('SHARED_SECRET'));
 $Backend = new Backend($base_url,$rest_user,$rest_pass,$filterString);
 
-$PermaQuery = new Query($permalink,$permaArchive,$bennoId);
+$PermaQuery = new Query($permalink,$bennoId);
 $PermaQuery->type = 'RepoPath';
 try {
     // fresh search, thus we start with position 1
