@@ -36,7 +36,7 @@ $extForm = $App->getParam('ext');
 $queryId = sha1(serialize($extForm));
 
 try {
-    $ExtQuery = new Query($queryId,$archive,
+    $ExtQuery = new Query($queryId,
             $extForm['text'],
             DateConvert::Date2Timestamp($extForm['dateFrom'],$App->date_format),
             DateConvert::Date2Timestamp($extForm['dateTo'],$App->date_format),
@@ -52,25 +52,12 @@ try {
     $ExtQuery->type = $App->getSession('searchMaskState');
 
     $App->setSession('isSpam',@$extForm['isSpam']);
-
-    // reset simple query
-    $SimpleQuery = new Query('empty');
-
-    $sessionMailId = '';
-    // fresh search, thus we start with position 1
-    $QueryResult = $Backend->query($archive,$ExtQuery,0,$search_limit);
-    if ($QueryResult->found == 0) {
-        $App->setMsg('MSG_NOTFOUND');
-    }
-    else {
-        $sessionMailId = $QueryResult->getSessionMailId(0);
-    }
 }
 catch (Exception $e) {
     $App->log('[searchExt] '.$e->getMessage());
     $App->setMsg($e->getMessage());
 }
 
-$App->view = 'showList';
-
+$redirect_params['queryData'] = $ExtQuery->getUrlParameter();
+$App->redirect('searchQuery',$redirect_params);
 ?>
