@@ -30,35 +30,14 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
-
-require_once 'model/DateConvert.php';
-
-
-$timeslice = $App->getParam('search_min_select');
-list($date_from,$date_to) = DateConvert::DateDiff($timeslice);
-
 $searchstring = $App->getParam('searchmin');
 
 $queryId = sha1($searchstring);
 try {
-    $SimpleQuery = new Query($queryId,$archive,$searchstring,$date_from,$date_to);
+    $SimpleQuery = new Query($queryId,$searchstring,$date_from,$date_to);
     $SimpleQuery->setSortOrder($sortOrder);
     $SimpleQuery->setSpam($App->getConfig('SHOW_SPAM',1));
     $SimpleQuery->type = $App->getSession('searchMaskState');
-
-    // reset extended query
-    $ExtQuery = new Query('empty');
-
-    $QueryResult = new QueryResult('','','');
-    $sessionMailId = '';
-    // fresh search, thus we start with position 1
-    $QueryResult = $Backend->query($archive,$SimpleQuery,0,$search_limit);
-    if ($QueryResult->found == 0) {
-        $App->setMsg('MSG_NOTFOUND');
-    }
-    else {
-        $sessionMailId = $QueryResult->getSessionMailId(0);
-    }
 }
 catch (Exception $e) {
     if ($e->getMessage() == 'ID_NOT_FOUND') {
@@ -70,6 +49,6 @@ catch (Exception $e) {
     }
 }
 
-$App->view = 'showList';
-
+$redirect_params['queryData'] = $SimpleQuery->getUrlParameter();
+$App->redirect('searchQuery',$redirect_params);
 ?>
