@@ -61,12 +61,22 @@ if ($USER->role == 'ADMIN') {
 
 $atm_list = array();
 foreach ($EMail->getAttachments() as $Attachment) {
+
+    $openWindow = false;
+    $show_inline = $App->getConfigList('ATTACHMENT_INLINE',array('application/pdf','image/png'));
+    if (in_array($Attachment->type,$show_inline)) {
+        $openWindow = true;        // open attachment inline
+    }
+
     $atm['id']           = urlencode($Attachment->id);
     $atm['attachmentId'] = $Attachment->attachmentId;
     $atm['type']         = $Attachment->type;
     $atm['size']         = $Attachment->size;
     $atm['icon']         = $Attachment->getIcon();
+    $atm['openWindow']   = $openWindow;
     array_push($atm_list,$atm);
+
+
 }
 $MailObject->attachments= $atm_list;
 
