@@ -38,5 +38,9 @@ $App->assign('auth_error',$auth_error);
 if ($App->getConfig('ADMIN_FOUREYES')) {
     $App->assign('ADMIN_FOUREYE',true);
 }
+if ($App->getConfig('LOGIN_AZURE')) {
+    $App->assign('LOGIN_AZURE',true);
+    $App->assign('LOGIN_AZURE_LINK',$App->getConfig('LOGIN_AZURE_LINK','/auth/azure'));
+}
 
 ?>
